==> odoo14_addon_mass_mailing_subscription_email-14.0.1.0.1.dev3-py3-none-any.whl: odoo/addons/mass_mailing_subscription_email/tests/test_subscription_email.py <==
# Copyright 2021 Camptocamp (http://www.camptocamp.com).
# @author Iván Todorovich <ivan.todorovich@gmail.com>
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from odoo.tests.common import SavepointCase

from odoo.addons.mail.tests.common import MockEmail


class TestSubscriptionEmail(SavepointCase, MockEmail):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.env = cls.env(context=dict(cls.env.context, tracking_disable=True))
        cls.mailing_list = cls.env.ref("mass_mailing.mailing_list_data")
        cls.mailing_contact = cls.env["mailing.contact"].create(
            {
                "name": "John Doe",
                "email": "john.doe@example.com",
            }
        )
        module_name = "mass_mailing_subscription_email"
        cls.subscribe_tmpl = cls.env.ref(f"{module_name}.mailing_list_subscribe")
        cls.unsubscribe_tmpl = cls.env.ref(f"{module_name}.mailing_list_unsubscribe")

    def test_subscription_email(self):
        # Set some tmpl values to ease tests
        email_from = "your-company@example.com"
        email_to = self.mailing_contact.email
        self.subscribe_tmpl.email_from = email_from
        self.unsubscribe_tmpl.email_from = email_from
        self.subscribe_tmpl.subject = "SUBSCRIBED"
        self.unsubscribe_tmpl.subject = "UNSUBSCRIBED"
        # Create subscription
        with self.mock_mail_gateway():
            subs = self.env["mailing.contact.subscription"].create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertEqual(self._new_mails.email_from, email_from)
        self.assertEqual(self._new_mails.email_to, email_to)
        self.assertEqual(self._new_mails.subject, "SUBSCRIBED")
        # Unsubscribe
        with self.mock_mail_gateway():
            subs.opt_out = True
        self.assertEqual(self._new_mails.email_from, email_from)
        self.assertEqual(self._new_mails.email_to, email_to)
        self.assertEqual(self._new_mails.subject, "UNSUBSCRIBED")
        # Subscribe again
        with self.mock_mail_gateway():
            subs.opt_out = False
        self.assertEqual(self._new_mails.email_from, email_from)
        self.assertEqual(self._new_mails.email_to, email_to)
        self.assertEqual(self._new_mails.subject, "SUBSCRIBED")
        # Unsubscribe through unlinking
        with self.mock_mail_gateway():
            subs.unlink()
        self.assertEqual(self._new_mails.email_from, email_from)
        self.assertEqual(self._new_mails.email_to, email_to)
        self.assertEqual(self._new_mails.subject, "UNSUBSCRIBED")

    def test_subscription_email_disabled(self):
        self.mailing_list.subscribe_template_id = False
        self.mailing_list.unsubscribe_template_id = False
        # Create subscription
        with self.mock_mail_gateway():
            subs = self.env["mailing.contact.subscription"].create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertFalse(self._new_mails)
        # Unsubscribe
        with self.mock_mail_gateway():
            subs.opt_out = True
        self.assertFalse(self._new_mails)
        # Subscribe again
        with self.mock_mail_gateway():
            subs.opt_out = False
        self.assertFalse(self._new_mails)
        # Unsubscribe through unlinking
        with self.mock_mail_gateway():
            subs.unlink()
        self.assertFalse(self._new_mails)

    def test_skip_subscription_email_context(self):
        # Create subscription
        with self.mock_mail_gateway():
            Subscription = self.env["mailing.contact.subscription"]
            Subscription.with_context(skip_subscription_email=True).create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertFalse(self._new_mails)

==> odoo14_addon_mass_mailing_subscription_email-14.0.1.0.2-py3-none-any.whl: odoo/addons/mass_mailing_subscription_email/tests/test_subscription_email.py <==
# Copyright 2021 Camptocamp (http://www.camptocamp.com).
# @author Iván Todorovich <ivan.todorovich@gmail.com>
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from odoo.tests.common import SavepointCase

from odoo.addons.mail.tests.common import MockEmail


class TestSubscriptionEmail(SavepointCase, MockEmail):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        cls.env = cls.env(context=dict(cls.env.context, tracking_disable=True))
        cls.mailing_list = cls.env.ref("mass_mailing.mailing_list_data")
        cls.mailing_contact = cls.env["mailing.contact"].create(
            {
                "name": "John Doe",
                "email": "john.doe@example.com",
            }
        )
        module_name = "mass_mailing_subscription_email"
        cls.subscribe_tmpl = cls.env.ref(f"{module_name}.mailing_list_subscribe")
        cls.unsubscribe_tmpl = cls.env.ref(f"{module_name}.mailing_list_unsubscribe")
        # Set some tmpl values to ease tests
        cls.email_from = "your-company@example.com"
        cls.subscribe_tmpl.email_from = cls.email_from
        cls.subscribe_tmpl.subject = "SUBSCRIBED"
        cls.unsubscribe_tmpl.email_from = cls.email_from
        cls.unsubscribe_tmpl.subject = "UNSUBSCRIBED"

    def test_subscription_email(self):
        # Create subscription
        with self.mock_mail_gateway():
            subs = self.env["mailing.contact.subscription"].create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertEqual(self._new_mails.email_from, self.email_from)
        self.assertEqual(self._new_mails.email_to, self.mailing_contact.email)
        self.assertEqual(self._new_mails.subject, "SUBSCRIBED")
        # Unsubscribe
        with self.mock_mail_gateway():
            subs.opt_out = True
        self.assertEqual(self._new_mails.email_from, self.email_from)
        self.assertEqual(self._new_mails.email_to, self.mailing_contact.email)
        self.assertEqual(self._new_mails.subject, "UNSUBSCRIBED")
        # Subscribe again
        with self.mock_mail_gateway():
            subs.opt_out = False
        self.assertEqual(self._new_mails.email_from, self.email_from)
        self.assertEqual(self._new_mails.email_to, self.mailing_contact.email)
        self.assertEqual(self._new_mails.subject, "SUBSCRIBED")
        # Unsubscribe through unlinking
        with self.mock_mail_gateway():
            subs.unlink()
        self.assertEqual(self._new_mails.email_from, self.email_from)
        self.assertEqual(self._new_mails.email_to, self.mailing_contact.email)
        self.assertEqual(self._new_mails.subject, "UNSUBSCRIBED")

    def test_subscription_email_disabled(self):
        self.mailing_list.subscribe_template_id = False
        self.mailing_list.unsubscribe_template_id = False
        # Create subscription
        with self.mock_mail_gateway():
            subs = self.env["mailing.contact.subscription"].create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertFalse(self._new_mails)
        # Unsubscribe
        with self.mock_mail_gateway():
            subs.opt_out = True
        self.assertFalse(self._new_mails)
        # Subscribe again
        with self.mock_mail_gateway():
            subs.opt_out = False
        self.assertFalse(self._new_mails)
        # Unsubscribe through unlinking
        with self.mock_mail_gateway():
            subs.unlink()
        self.assertFalse(self._new_mails)

    def test_skip_subscription_email_context(self):
        # Create subscription
        with self.mock_mail_gateway():
            Subscription = self.env["mailing.contact.subscription"]
            Subscription.with_context(skip_subscription_email=True).create(
                {
                    "contact_id": self.mailing_contact.id,
                    "list_id": self.mailing_list.id,
                }
            )
        self.assertFalse(self._new_mails)
